@@ -6,10 +6,9 @@
 from typing import Any, Callable, Optional, Union
 
 import qtawesome as qta
-from qtpy import QtWidgets, QtGui
-
-from prettyqt import core, widgets, gui
+from qtpy import QtGui, QtWidgets
 
+from prettyqt import core, gui, widgets
 
 QtWidgets.QMenu.__bases__ = (widgets.Widget,)
 
@@ -47,24 +46,26 @@ class Menu(QtWidgets.QMenu):
             icon = qta.icon(icon)
         self.setIcon(icon)
 
-    def add_separator(self):
-        self.addSeparator()
-
-    def _separator(self, text: str) -> widgets.WidgetAction:
-        """returns a separator showing a label
+    def add_separator(self, text: Optional[str] = None) -> widgets.WidgetAction:
+        """adds a separator showing an optional label
 
         Args:
             text: Text to show on separator
 
         Returns:
-            Separator widget
+            Separator action
         """
-        label = widgets.Label(text)
-        label.setMinimumWidth(self.minimumWidth())
-        label.setStyleSheet("background:lightgrey")
-        label.set_alignment(horizontal="center")
         separator = widgets.WidgetAction(parent=self)
-        separator.setDefaultWidget(label)
+        if text is None:
+            separator.setSeparator(True)
+        else:
+            label = widgets.Label(text)
+            label.setMinimumWidth(self.minimumWidth())
+            label.setStyleSheet("background:lightgrey")
+            label.set_alignment(horizontal="center")
+            separator = widgets.WidgetAction(parent=self)
+            separator.setDefaultWidget(label)
+        self.add(separator)
         return separator
 
     def add_action(self,
